@@ -381,10 +381,10 @@ public class Entry extends Widget implements Editable {
 		fireEntryEvent(ee);
 	}
 
-	private void handleInsertText(String text, int length, int position) {
+	private void handleInsertText(String text, int length, Handle position) {
 		EntryEvent ee = new EntryEvent(this, EntryEvent.Type.INSERT_TEXT);
 		ee.setText(text);
-		ee.setInsertPosition(position);
+		ee.setInsertPosition(getIntFromHandle(position));
 		fireEntryEvent(ee);
 	}
 	
